@@ -59,7 +59,7 @@ _object_setattr = _model_construction.object_setattr
 
 
 class BaseModel(metaclass=_model_construction.ModelMetaclass):
-    """usage docs: https://docs.pydantic.dev/2.0/usage/models/
+    """Usage docs: https://docs.pydantic.dev/2.2/usage/models/
 
     A base class for creating Pydantic models.
 
@@ -159,7 +159,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         __pydantic_self__.__pydantic_validator__.validate_python(data, self_instance=__pydantic_self__)
 
     # The following line sets a flag that we use to determine when `__init__` gets overridden by the user
-    __init__.__pydantic_base_init__ = True  # type: ignore
+    __init__.__pydantic_base_init__ = True
 
     @property
     def model_computed_fields(self) -> dict[str, ComputedFieldInfo]:
@@ -278,7 +278,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         round_trip: bool = False,
         warnings: bool = True,
     ) -> dict[str, Any]:
-        """Usage docs: https://docs.pydantic.dev/dev-v2/usage/serialization/#modelmodel_dump
+        """Usage docs: https://docs.pydantic.dev/2.2/usage/serialization/#modelmodel_dump
 
         Generate a dictionary representation of the model, optionally specifying which fields to include or exclude.
 
@@ -324,7 +324,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         round_trip: bool = False,
         warnings: bool = True,
     ) -> str:
-        """Usage docs: https://docs.pydantic.dev/dev-v2/usage/serialization/#modelmodel_dump_json
+        """Usage docs: https://docs.pydantic.dev/2.2/usage/serialization/#modelmodel_dump_json
 
         Generates a JSON representation of the model using Pydantic's `to_json` method.
 
@@ -368,7 +368,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         Args:
             by_alias: Whether to use attribute aliases or not.
             ref_template: The reference template.
-            schema_generator: To override the logic used to generate the JSON schema, ass a subclass of
+            schema_generator: To override the logic used to generate the JSON schema, as a subclass of
                 `GenerateJsonSchema` with your desired modifications
             mode: The mode in which to generate the schema.
 
@@ -396,7 +396,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         Raises:
             TypeError: Raised when trying to generate concrete names for non-generic models.
         """
-        if not issubclass(cls, typing.Generic):  # type: ignore[arg-type]
+        if not issubclass(cls, typing.Generic):
             raise TypeError('Concrete names should only be generated for generic models.')
 
         # Any strings received should represent forward references, so we handle them specially below.
@@ -748,6 +748,13 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
                 'input': value,
             }
             raise pydantic_core.ValidationError.from_exception_data(self.__class__.__name__, [error])
+        elif getattr(self.model_fields.get(name), 'frozen', False):
+            error: pydantic_core.InitErrorDetails = {
+                'type': 'frozen_field',
+                'loc': (name,),
+                'input': value,
+            }
+            raise pydantic_core.ValidationError.from_exception_data(self.__class__.__name__, [error])
 
         attr = getattr(self.__class__, name, None)
         if isinstance(attr, property):
@@ -1109,7 +1116,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         )
 
         values = dict(
-            _deprecated_copy_internals._iter(  # type: ignore
+            _deprecated_copy_internals._iter(
                 self, to_dict=False, by_alias=False, include=include, exclude=exclude, exclude_unset=False
             ),
             **(update or {}),
@@ -1200,7 +1207,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
     )
     def _iter(self, *args: Any, **kwargs: Any) -> Any:
         warnings.warn('The private method `_iter` will be removed and should no longer be used.', DeprecationWarning)
-        return _deprecated_copy_internals._iter(self, *args, **kwargs)  # type: ignore
+        return _deprecated_copy_internals._iter(self, *args, **kwargs)
 
     @typing_extensions.deprecated(
         'The private method `_copy_and_set_values` will be removed and should no longer be used.',
@@ -1211,7 +1218,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
             'The private method  `_copy_and_set_values` will be removed and should no longer be used.',
             DeprecationWarning,
         )
-        return _deprecated_copy_internals._copy_and_set_values(self, *args, **kwargs)  # type: ignore
+        return _deprecated_copy_internals._copy_and_set_values(self, *args, **kwargs)
 
     @classmethod
     @typing_extensions.deprecated(
@@ -1222,7 +1229,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         warnings.warn(
             'The private method  `_get_value` will be removed and should no longer be used.', DeprecationWarning
         )
-        return _deprecated_copy_internals._get_value(cls, *args, **kwargs)  # type: ignore
+        return _deprecated_copy_internals._get_value(cls, *args, **kwargs)
 
     @typing_extensions.deprecated(
         'The private method `_calculate_keys` will be removed and should no longer be used.',
@@ -1232,7 +1239,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         warnings.warn(
             'The private method `_calculate_keys` will be removed and should no longer be used.', DeprecationWarning
         )
-        return _deprecated_copy_internals._calculate_keys(self, *args, **kwargs)  # type: ignore
+        return _deprecated_copy_internals._calculate_keys(self, *args, **kwargs)
 
 
 @typing.overload
@@ -1287,8 +1294,7 @@ def create_model(
         __cls_kwargs__: A dictionary of keyword arguments for class creation.
         __slots__: Deprecated. Should not be passed to `create_model`.
         **field_definitions: Attributes of the new model. They should be passed in the format:
-            `<name>=(<type>, <default value>)` or `<name>=<default value>`. For more complex cases, they can be
-            passed in the format: `<name>=<Field>` or `<name>=(<type>, <FieldInfo>)`.
+            `<name>=(<type>, <default value>)` or `<name>=(<type>, <FieldInfo>)`.
 
     Returns:
         The new [model][pydantic.BaseModel].
