@@ -3,10 +3,18 @@ from typing import Tuple
 
 __all__ = 'VERSION', 'version_info'
 
-VERSION = '2.0.3'
+VERSION = '2.2.0'
 """The version of Pydantic."""
 
 
+def version_short() -> str:
+    """Return the major.minor part of Pydantic version.
+
+    It return '2.1' if Pydantic version is '2.1.1'.
+    """
+    return '.'.join(VERSION.split('.')[:2])
+
+
 def version_info() -> str:
     """Return complete version information for Pydantic and its dependencies."""
     import platform
@@ -26,7 +34,8 @@ def version_info() -> str:
 
     info = {
         'pydantic version': VERSION,
-        'pydantic-core version': f'{pdc.__version__} {pdc.build_profile} build profile',
+        'pydantic-core version': pdc.__version__,
+        'pydantic-core build': getattr(pdc, 'build_info', None) or pdc.build_profile,
         'install path': Path(__file__).resolve().parent,
         'python version': sys.version,
         'platform': platform.platform(),
