@@ -116,9 +116,9 @@ def time_model_fixture():
         ('10:20:30.400', time(10, 20, 30, 400_000)),
         (b'10:20:30.400', time(10, 20, 30, 400_000)),
         (time(4, 8, 16), time(4, 8, 16)),
-        (3610, time(1, 0, 10)),
-        (3600.5, time(1, 0, 0, 500000)),
-        (86400 - 1, time(23, 59, 59)),
+        (3610, time(1, 0, 10, tzinfo=timezone.utc)),
+        (3600.5, time(1, 0, 0, 500000, tzinfo=timezone.utc)),
+        (86400 - 1, time(23, 59, 59, tzinfo=timezone.utc)),
         # Invalid inputs
         ('4:8:16', Err('Input should be in a valid time format, invalid character in hour [type=time_parsing,')),
         (86400, Err('Input should be in a valid time format, numeric times may not exceed 86,399 seconds')),
@@ -158,10 +158,10 @@ def datetime_model_fixture():
     [
         # Valid inputs
         # values in seconds
-        (1_494_012_444.883_309, datetime(2017, 5, 5, 19, 27, 24, 883_309)),
-        (1_494_012_444, datetime(2017, 5, 5, 19, 27, 24)),
+        (1_494_012_444.883_309, datetime(2017, 5, 5, 19, 27, 24, 883_309, tzinfo=timezone.utc)),
+        (1_494_012_444, datetime(2017, 5, 5, 19, 27, 24, tzinfo=timezone.utc)),
         # values in ms
-        (1_494_012_444_000, datetime(2017, 5, 5, 19, 27, 24)),
+        (1_494_012_444_000, datetime(2017, 5, 5, 19, 27, 24, tzinfo=timezone.utc)),
         ('2012-04-23T09:15:00', datetime(2012, 4, 23, 9, 15)),
         ('2012-04-23T09:15:00Z', datetime(2012, 4, 23, 9, 15, 0, 0, timezone.utc)),
         ('2012-04-23T10:20:30.400+02:30', datetime(2012, 4, 23, 10, 20, 30, 400_000, create_tz(150))),
@@ -169,22 +169,22 @@ def datetime_model_fixture():
         ('2012-04-23T10:20:30.400-02:00', datetime(2012, 4, 23, 10, 20, 30, 400_000, create_tz(-120))),
         (b'2012-04-23T10:20:30.400-02:00', datetime(2012, 4, 23, 10, 20, 30, 400_000, create_tz(-120))),
         (datetime(2017, 5, 5), datetime(2017, 5, 5)),
-        (0, datetime(1970, 1, 1, 0, 0, 0)),
+        (0, datetime(1970, 1, 1, 0, 0, 0, tzinfo=timezone.utc)),
         # Numeric inputs as strings
-        ('1494012444.883309', datetime(2017, 5, 5, 19, 27, 24, 883309)),
-        ('1494012444', datetime(2017, 5, 5, 19, 27, 24)),
-        (b'1494012444', datetime(2017, 5, 5, 19, 27, 24)),
-        ('1494012444000.883309', datetime(2017, 5, 5, 19, 27, 24, 883301)),
-        ('-1494012444000.883309', datetime(1922, 8, 29, 4, 32, 35, 999000)),
+        ('1494012444.883309', datetime(2017, 5, 5, 19, 27, 24, 883309, tzinfo=timezone.utc)),
+        ('1494012444', datetime(2017, 5, 5, 19, 27, 24, tzinfo=timezone.utc)),
+        (b'1494012444', datetime(2017, 5, 5, 19, 27, 24, tzinfo=timezone.utc)),
+        ('1494012444000.883309', datetime(2017, 5, 5, 19, 27, 24, 883301, tzinfo=timezone.utc)),
+        ('-1494012444000.883309', datetime(1922, 8, 29, 4, 32, 35, 999000, tzinfo=timezone.utc)),
         # Invalid inputs
         ('2012-4-9 4:8:16', Err('Input should be a valid datetime, invalid character in month')),
         ('x20120423091500', Err('Input should be a valid datetime, invalid character in year')),
         ('2012-04-56T09:15:90', Err('Input should be a valid datetime, day value is outside expected range')),
         ('2012-04-23T11:05:00-25:00', Err('Input should be a valid datetime, timezone offset must be less than 24 ho')),
-        (19_999_999_999, datetime(2603, 10, 11, 11, 33, 19)),  # just before watershed
-        (20_000_000_001, datetime(1970, 8, 20, 11, 33, 20, 1000)),  # just after watershed
-        (1_549_316_052, datetime(2019, 2, 4, 21, 34, 12, 0)),  # nowish in s
-        (1_549_316_052_104, datetime(2019, 2, 4, 21, 34, 12, 104_000)),  # nowish in ms
+        (19_999_999_999, datetime(2603, 10, 11, 11, 33, 19, tzinfo=timezone.utc)),  # just before watershed
+        (20_000_000_001, datetime(1970, 8, 20, 11, 33, 20, 1000, tzinfo=timezone.utc)),  # just after watershed
+        (1_549_316_052, datetime(2019, 2, 4, 21, 34, 12, 0, tzinfo=timezone.utc)),  # nowish in s
+        (1_549_316_052_104, datetime(2019, 2, 4, 21, 34, 12, 104_000, tzinfo=timezone.utc)),  # nowish in ms
         (1_549_316_052_104_324, Err('Input should be a valid datetime, dates after 9999')),  # nowish in μs
         (1_549_316_052_104_324_096, Err('Input should be a valid datetime, dates after 9999')),  # nowish in ns
         ('infinity', Err('Input should be a valid datetime, input is too short')),
