@@ -437,16 +437,9 @@ def test_tuple_value_error():
             'msg': 'Input should be a valid number, unable to parse string as a number',
             'input': 'y',
         },
-        {
-            'type': 'is_instance_of',
-            'loc': ('v', 2, 'is-instance[Decimal]'),
-            'msg': 'Input should be an instance of Decimal',
-            'input': 'x',
-            'ctx': {'class': 'Decimal'},
-        },
         {
             'type': 'decimal_parsing',
-            'loc': ('v', 2, 'function-after[to_decimal(), union[int,constrained-str,function-plain[str()]]]'),
+            'loc': ('v', 2),
             'msg': 'Input should be a valid decimal',
             'input': 'x',
         },
@@ -1233,24 +1226,9 @@ def test_multiple_errors():
             'msg': 'Input should be a valid number, unable to parse string as a number',
             'input': 'foobar',
         },
-        {
-            'type': 'is_instance_of',
-            'loc': (
-                'a',
-                'function-after[check_digits_validator(), json-or-python[json=function-after[to_decimal(), union[int,constrained-str,function-plain[str()]]],python=lax-or-strict[lax=union[is-instance[Decimal],function-after[to_decimal(), union[int,constrained-str,function-plain[str()]]]],strict=is-instance[Decimal]]]]',
-                'is-instance[Decimal]',
-            ),
-            'msg': 'Input should be an instance of Decimal',
-            'input': 'foobar',
-            'ctx': {'class': 'Decimal'},
-        },
         {
             'type': 'decimal_parsing',
-            'loc': (
-                'a',
-                'function-after[check_digits_validator(), json-or-python[json=function-after[to_decimal(), union[int,constrained-str,function-plain[str()]]],python=lax-or-strict[lax=union[is-instance[Decimal],function-after[to_decimal(), union[int,constrained-str,function-plain[str()]]]],strict=is-instance[Decimal]]]]',
-                'function-after[to_decimal(), union[int,constrained-str,function-plain[str()]]]',
-            ),
+            'loc': ('a', 'decimal'),
             'msg': 'Input should be a valid decimal',
             'input': 'foobar',
         },
@@ -2580,3 +2558,13 @@ def test_union_literal_with_other_type(literal_type, other_type, data, json_valu
     m = Model(value=data, value_types_reversed=data)
     assert m.model_dump() == {'value': data, 'value_types_reversed': data_reversed}
     assert m.model_dump_json() == f'{{"value":{json_value},"value_types_reversed":{json_value_reversed}}}'
+
+
+def test_type_union():
+    class Model(BaseModel):
+        a: Type[Union[str, bytes]]
+        b: Type[Union[Any, str]]
+
+    m = Model(a=bytes, b=int)
+    assert m.model_dump() == {'a': bytes, 'b': int}
+    assert m.a == bytes
