@@ -1,15 +1,12 @@
+import sys
 from inspect import Parameter, Signature, signature
-from typing import Any, Iterable, Optional, Union
+from typing import Any, Generic, Iterable, Optional, TypeVar, Union
 
+import pytest
 from typing_extensions import Annotated
 
-from pydantic import BaseModel, Extra, Field, create_model
-from pydantic.version import compiled
-
-# Cython 3.x uses stringified annotations by default. When a signature is generated
-# for Pydantic models, we use the `BaseModel.__init__` signature which has a type
-# of `Any` for the data. This annotation is reused and will be stringified only when compiled:
-Any_ann = "'Any'" if compiled else 'Any'
+from pydantic import BaseModel, ConfigDict, Field, create_model
+from pydantic._internal._typing_extra import is_annotated
 
 
 def _equals(a: Union[str, Iterable[str]], b: Union[str, Iterable[str]]) -> bool:
@@ -27,7 +24,7 @@ def _equals(a: Union[str, Iterable[str]], b: Union[str, Iterable[str]]) -> bool:
 def test_model_signature():
     class Model(BaseModel):
         a: float = Field(..., title='A')
-        b = Field(10)
+        b: int = Field(10)
 
     sig = signature(Model)
     assert sig != signature(BaseModel)
@@ -35,14 +32,25 @@ def test_model_signature():
     assert _equals(str(sig), '(*, a: float, b: int = 10) -> None')
 
 
+def test_generic_model_signature():
+    T = TypeVar('T')
+
+    class Model(BaseModel, Generic[T]):
+        a: T
+
+    sig = signature(Model[int])
+    assert sig != signature(BaseModel)
+    assert _equals(map(str, sig.parameters.values()), ('a: int',))
+    assert _equals(str(sig), '(*, a: int) -> None')
+
+
 def test_custom_init_signature():
     class MyModel(BaseModel):
         id: int
         name: str = 'John Doe'
         f__: str = Field(..., alias='foo')
 
-        class Config:
-            extra = Extra.allow
+        model_config = ConfigDict(extra='allow')
 
         def __init__(self, id: int = 1, bar=2, *, baz: Any, **data):
             super().__init__(id=id, **data)
@@ -67,27 +75,26 @@ def test_custom_init_signature_with_no_var_kw():
         def __init__(self, a: float, b: int):
             super().__init__(a=a, b=b, c=1)
 
-        class Config:
-            extra = Extra.allow
+        model_config = ConfigDict(extra='allow')
 
     assert _equals(str(signature(Model)), '(a: float, b: int) -> None')
 
 
 def test_invalid_identifiers_signature():
     model = create_model(
-        'Model', **{'123 invalid identifier!': Field(123, alias='valid_identifier'), '!': Field(0, alias='yeah')}
+        'Model',
+        **{'123 invalid identifier!': (int, Field(123, alias='valid_identifier')), '!': (int, Field(0, alias='yeah'))},
     )
     assert _equals(str(signature(model)), '(*, valid_identifier: int = 123, yeah: int = 0) -> None')
-    model = create_model('Model', **{'123 invalid identifier!': 123, '!': Field(0, alias='yeah')})
-    assert _equals(str(signature(model)), f'(*, yeah: int = 0, **extra_data: {Any_ann}) -> None')
+    model = create_model('Model', **{'123 invalid identifier!': (int, 123), '!': (int, Field(0, alias='yeah'))})
+    assert _equals(str(signature(model)), '(*, yeah: int = 0, **extra_data: Any) -> None')
 
 
 def test_use_field_name():
     class Foo(BaseModel):
         foo: str = Field(..., alias='this is invalid')
 
-        class Config:
-            allow_population_by_field_name = True
+        model_config = ConfigDict(populate_by_name=True)
 
     assert _equals(str(signature(Foo)), '(*, foo: str) -> None')
 
@@ -96,8 +103,7 @@ def test_does_not_use_reserved_word():
     class Foo(BaseModel):
         from_: str = Field(..., alias='from')
 
-        class Config:
-            allow_population_by_field_name = True
+        model_config = ConfigDict(populate_by_name=True)
 
     assert _equals(str(signature(Foo)), '(*, from_: str) -> None')
 
@@ -106,20 +112,18 @@ def test_extra_allow_no_conflict():
     class Model(BaseModel):
         spam: str
 
-        class Config:
-            extra = Extra.allow
+        model_config = ConfigDict(extra='allow')
 
-    assert _equals(str(signature(Model)), f'(*, spam: str, **extra_data: {Any_ann}) -> None')
+    assert _equals(str(signature(Model)), '(*, spam: str, **extra_data: Any) -> None')
 
 
 def test_extra_allow_conflict():
     class Model(BaseModel):
         extra_data: str
 
-        class Config:
-            extra = Extra.allow
+        model_config = ConfigDict(extra='allow')
 
-    assert _equals(str(signature(Model)), f'(*, extra_data: str, **extra_data_: {Any_ann}) -> None')
+    assert _equals(str(signature(Model)), '(*, extra_data: str, **extra_data_: Any) -> None')
 
 
 def test_extra_allow_conflict_twice():
@@ -127,10 +131,9 @@ def test_extra_allow_conflict_twice():
         extra_data: str
         extra_data_: str
 
-        class Config:
-            extra = Extra.allow
+        model_config = ConfigDict(extra='allow')
 
-    assert _equals(str(signature(Model)), f'(*, extra_data: str, extra_data_: str, **extra_data__: {Any_ann}) -> None')
+    assert _equals(str(signature(Model)), '(*, extra_data: str, extra_data_: str, **extra_data__: Any) -> None')
 
 
 def test_extra_allow_conflict_custom_signature():
@@ -140,8 +143,7 @@ def test_extra_allow_conflict_custom_signature():
         def __init__(self, extra_data: int = 1, **foobar: Any):
             super().__init__(extra_data=extra_data, **foobar)
 
-        class Config:
-            extra = Extra.allow
+        model_config = ConfigDict(extra='allow')
 
     assert _equals(str(signature(Model)), '(extra_data: int = 1, **foobar: Any) -> None')
 
@@ -167,20 +169,24 @@ def test_optional_field():
     )
 
 
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='repr different on older versions')
 def test_annotated_field():
+    from annotated_types import Gt
+
     class Model(BaseModel):
-        foo: Annotated[int, 'foo'] = 1
+        foo: Annotated[int, Gt(1)] = 1
 
-    assert signature(Model) == Signature(
-        [Parameter('foo', Parameter.KEYWORD_ONLY, default=1, annotation=Annotated[int, 'foo'])], return_annotation=None
-    )
+    sig = signature(Model)
+    assert str(sig) == '(*, foo: typing.Annotated[int, Gt(gt=1)] = 1) -> None'
+    # check that the `Annotated` we created is a valid `Annotated`
+    assert is_annotated(sig.parameters['foo'].annotation)
 
 
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='repr different on older versions')
 def test_annotated_optional_field():
-    class Model(BaseModel):
-        foo: Annotated[Optional[int], 'foo'] = None
+    from annotated_types import Gt
 
-    assert signature(Model) == Signature(
-        [Parameter('foo', Parameter.KEYWORD_ONLY, default=None, annotation=Annotated[Optional[int], 'foo'])],
-        return_annotation=None,
-    )
+    class Model(BaseModel):
+        foo: Annotated[Optional[int], Gt(1)] = None
+
+    assert str(signature(Model)) == '(*, foo: Annotated[Optional[int], Gt(gt=1)] = None) -> None'
